# ACP to MCP Adapter

Lightweight standalone MCP server acting as an adapter for ACP agents into the MCP ecosystem.

## Capablities

- Agent descriptions as Resources
- Agent runs as Tools

## Transports

- Stdio
